package dunolint-lib

  1. Overview
  2. Docs

Module Dunolint.ConfigSource

Sourcetype t
include Ppx_compare_lib.Comparable.S with type t := t
Sourceval compare : t -> t -> int
include Ppx_compare_lib.Equal.S with type t := t
Sourceval equal : t -> t -> bool
include Sexplib0.Sexpable.S with type t := t
Sourceval t_of_sexp : Sexplib0.Sexp.t -> t
Sourceval sexp_of_t : t -> Sexplib0.Sexp.t

Getters

Skip subtree

This part relate to making dunolint ignor parts of your project, namely not visiting entire sub directories of your repo.

Sourcemodule Skip_subtree : sig ... end
Sourceval skip_subtree : t -> Skip_subtree.t Base.option

Generic rules

Sourcemodule Rule : sig ... end
Sourceval rules : t -> Rule.t Base.list

Creating configs

Sourceval create : ?skip_subtree:Skip_subtree.t -> ?rules:Rule.t Base.list -> Base.unit -> t

An EDSL to build configs

Sourcemodule Std : sig ... end